@@ -17,13 +17,14 @@ def handle_status_code(func):
         try:
             return func(*args, **kwargs)
         except Exception as err:
-            if not err.response:
-                raise Exception(err)
-            elif err.response.status_code == 401:
-                raise Exception("API credentials not correct.")
+            if err.response is not None:
+                if err.response.status_code == 401:
+                    raise Exception("API credentials not correct.")
+                elif hasattr(err.response, "_content"):
+                    raise Exception(str(err.response._content, "utf-8"))
+                else:
+                    raise Exception(err)
             else:
-                raise Exception(
-                    f"{err}\n Response: {str(err.response._content, 'utf-8')}"
-                )
+                raise Exception(err)
 
     return decorator
